Performance - AI Machine
Description: Performance benchmarks and metrics for AI Machine products.

# Performance Benchmarks

Industry-leading metrics and real-world performance

10x
Faster Training

Compared to traditional cloud providers

500
TOPS

Peak performance per server

60%
Cost Savings

vs public cloud

## Benchmark Results

Benchmark | AI Machine | Competitor A | Competitor B
--- | --- | --- | ---
MLPerf Training | ✓ 2,450 | 1,890 | 1,650
MLPerf Inference | ✓ 8,920 | 6,780 | 7,120
ResNet-50 Training | ✓ 45 min | 78 min | 65 min
BERT Training | ✓ 3.2 hrs | 5.8 hrs | 4.9 hrs

View Products See Case Studies